Make ubuntu:artful default for unit test docker

Similar to other changes in this repo, specify the default ubuntu release
so as to not be at the whim of ubuntu:latest

Change-Id: I01ce642252f882d539b7d42d4a106d1839323a96
Signed-off-by: Andrew Geissler <geissonator@yahoo.com>
diff --git a/build-unit-test-docker.sh b/build-unit-test-docker.sh
index b91526b..771d2d8 100755
--- a/build-unit-test-docker.sh
+++ b/build-unit-test-docker.sh
@@ -6,12 +6,12 @@
 #   param1:  <optional, the name of the docker image to generate>
 #            default is openbmc/ubuntu-unit-test
 #   param2:  <optional, the distro to build a docker image against>
 #            default is ubuntu:latest
 
 set -uo pipefail
 
 DOCKER_IMG_NAME=${1:-"openbmc/ubuntu-unit-test"}
-DISTRO=${2:-"ubuntu:latest"}
+DISTRO=${2:-"ubuntu:artful"}
 
 # Disable autom4te cache as workaround to permission issue
 AUTOM4TE_CFG="/root/.autom4te.cfg"
@@ -6,12 +6,12 @@
 #            default is openbmc/ubuntu-unit-test
 #   param2:  <optional, the distro to build a docker image against>
-#            default is ubuntu:latest
+#            default is ubuntu:artful
 
 set -uo pipefail